@@ -90,9 +90,13 @@ class Processing:
             if attr in self.kwargs.keys():
                 replacement[attr] = self.kwargs[attr]
             elif numb_name:
-                default_value = int(getattr(obj, attr))
-                if default_value < 0:
-                    numb_name = "-{}".format(numb_name)
+                default_value = getattr(obj, attr)
+                if not isinstance(default_value, list):
+                    default_value = int(default_value)
+                    if default_value < 0:
+                        numb_name = "-{}".format(numb_name)
+                else:
+                    continue
                 replacement[attr] = numb_name
             else:
                 replacement[attr] = getattr(obj, attr)
@@ -158,8 +162,10 @@ class Processing:
         if "grid_mapping" in self.ds[self.var_name[0]].attrs:
             gm = self.ds[self.var_name[0]].attrs["grid_mapping"]
             array.attrs["grid_mapping"] = gm
-        data_vars[self.CIname] = array
         coords = {k: v for k, v in self.ds.coords.items() if "time" not in k}
+        for k, v in coords.items():
+            array[k] = v
+        data_vars[self.CIname] = array
         idx_ds = xr.Dataset(
             data_vars=data_vars,
             coords=coords,
